-- PIS E COFINS

ALTER VIEW [dbo].[mxf_vw_pis_cofins]
AS
SELECT DISTINCT
	P.CODPROD AS codigo_produto, P.CODBARRA AS ean, P.DESCRICAO AS descritivo_produto, 
    N.CODNCM AS ncm, P.EX_IPI AS ncm_ex,
	NAT.cod_fis_natureza_receita_pis_cofins AS cod_natureza_receita, CST_PIS_E.cod_cst_pis AS pis_cst_e, 
    CST_PIS_S.cod_cst_pis AS pis_cst_s, P.PERCPIS_ENTRADA AS pis_alq_e, P.PERCPIS AS pis_alq_s, 
    CST_COFINS_E.cod_cst_cofins AS cofins_cst_e, CST_COFINS_S.cod_cst_cofins AS cofins_cst_s, 
    P.PERCCOFINS_ENTRADA AS cofins_alq_e, P.PERCCOFINS AS cofins_alq_s, null as depto, GE.DESCRICAO AS secao, 
    GR.GRUPO AS grupo, SG.DESCRICAO AS subgrupo, P.INATIVO AS status
FROM
	dbo.CDPRODUTOS AS P
		INNER JOIN dbo.CDGENEROS AS GE ON P.CODGENERO = GE.CODGENERO
		INNER JOIN dbo.CDGRUPOS AS GR ON P.CODGENERO = GR.CODGENERO AND P.CODGRUPO = GR.CODGRUPO
		LEFT JOIN dbo.CDSUBGRUPOS AS SG ON P.CODGENERO = SG.CODGENERO AND P.CODGRUPO = SG.CODGRUPO AND P.CODSUBGRUPO = SG.CODSUBGRUPO
		LEFT JOIN dbo.CDNCM AS N ON P.IDNCM = N.IDNCM
		LEFT JOIN fis_natureza_receita_pis_cofins AS NAT ON P.NAT_RECEITA_COFINS = NAT.id_fis_natureza_receita_pis_cofins
		LEFT JOIN fis_cst_pis AS CST_PIS_E ON P.CODCSTPIS_ENTRADA = CST_PIS_E.id_fis_cst_pis
		LEFT JOIN fis_cst_pis AS CST_PIS_S ON P.CODCSTPIS = CST_PIS_S.id_fis_cst_pis
		LEFT JOIN fis_cst_cofins AS CST_COFINS_E ON P.CODCSTCOFINS_ENTRADA = CST_COFINS_E.id_fis_cst_cofins
		LEFT JOIN fis_cst_cofins AS CST_COFINS_S ON P.CODCSTCOFINS = CST_COFINS_S.id_fis_cst_cofins
GO


-- ICMS
ALTER VIEW [dbo].[mxf_vw_icms]
AS
SELECT
	P.CODPROD AS codigo_produto, P.CODBARRA AS ean, NULL AS tipo_mva, P.PERCALIQSUBTRIB AS mva,
	SUBSTRING(T.SITTRIB, 2,2) AS sac_cst, c.CODCEST as cest, ANF.PERCENTUAL AS sac_alq, P.PERCALIQSUBTRIB AS sac_alqst, P.PERCREDUC AS sac_rbc, NULL AS sac_rbcst, 
	SUBSTRING(T.SITTRIB, 2,2) AS sas_cst, ANF.PERCENTUAL AS sas_alq, P.PERCALIQSUBTRIB AS sas_alqst, P.PERCREDUC AS sas_rbc, NULL AS sas_rbcst, 
	SUBSTRING(T.SITTRIB, 2,2) AS svc_cst, ANF.PERCENTUAL AS svc_alq, P.PERCALIQSUBTRIB AS svc_alqst, P.PERCREDUC AS svc_rbc, NULL AS svc_rbcst, 
	SUBSTRING(T.SITTRIB, 2,2) AS snc_cst, AECF.PERCENTUAL AS snc_alq, P.PERCALIQSUBTRIB AS snc_alqst, P.PERCREDUC AS snc_rbc, NULL AS snc_rbcst,
	TSN.SITTRIB AS sss_csosn,
	TSN.SITTRIB AS svc_csosn,
	TSN.SITTRIB AS snc_csosn,
	P.ALIQ_FCP AS fecp,
	ISNULL(P.INATIVO,'N') AS status
	
FROM
	CDPRODUTOS P
		INNER JOIN CDALIQUOTA ANF ON P.CODALIQNF = ANF.CODALIQ
		INNER JOIN CDALIQUOTA AECF ON P.CODALIQECF = AECF.CODALIQ
		LEFT JOIN CDTRIBUTACAO T ON P.CODTRIB = T.CODTRIB
		LEFT JOIN CDTRIBUTACAO TSN ON P.CODTRIBSN = TSN.CODTRIB
		LEFT JOIN CDCEST C ON C.ID_CEST = P.ID_CEST

GO

-- **********  CRIAÇÃO DAS PERMISSÕES DE ACESSO **********
GRANT SELECT, UPDATE, INSERT, DELETE ON mxf_tmp_pis_cofins TO MIX_FISCAL
GRANT SELECT, UPDATE, INSERT, DELETE ON mxf_tmp_icms_saida TO MIX_FISCAL
GRANT SELECT, UPDATE, INSERT, DELETE ON mxf_tmp_icms_entrada TO MIX_FISCAL

GRANT SELECT ON mxf_vw_pis_cofins TO MIX_FISCAL
GRANT SELECT ON mxf_vw_icms TO MIX_FISCAL
GO