--SCRIPTS MIX FISCAL

-- **********  CRIAO DAS TABELAS **********

-- PIS E COFINS
if Not Exists(select * from sys.tables where Name = N'mxf_tmp_pis_cofins')
BEGIN
	CREATE TABLE mxf_tmp_pis_cofins ( 
		codigo_produto numeric(11),
		ean numeric(16),
		ncm varchar(10),
		ncm_ex varchar(3),
		cod_natureza_receita numeric(4),
		credito_presumido numeric(1),
		pis_cst_e varchar(3),
		pis_cst_s varchar(3),
		pis_alq_e numeric(7,3),
		pis_alq_s numeric(7,3),
		cofins_cst_e varchar(3),
		cofins_cst_s varchar(3),
		cofins_alq_e numeric(7,3),
		cofins_alq_s numeric(7,3),
		fundamento_legal varchar(500)
	);
END
GO

-- ICMS DE SADA
if Not Exists(select * from sys.tables where Name = N'mxf_tmp_icms_saida')
BEGIN
	CREATE TABLE mxf_tmp_icms_saida ( 
		codigo_produto numeric(11),
		ean numeric(16),
		sac_cst varchar(3),
		sac_alq numeric(7,3),
		sac_alqst numeric(7,3),
		sac_rbc numeric(7,3),
		sav_rbcst numeric(7,3),
		sas_cst varchar(3),
		sas_alq numeric(7,3),
		sas_alqst numeric(7,3),
		sas_rbc numeric(7,3),
		sas_rbcst numeric(7,3),
		svc_cst varchar(3),
		svc_alq numeric(7,3),
		svc_alqst numeric(7,3),
		svc_rbc numeric(7,3),
		svc_rbcst numeric(7,3),
		snc_cst varchar(3),
		snc_alq numeric(7,3),
		snc_alqst numeric(7,3),
		snc_rbc numeric(7,3),
		snc_rbcst numeric(7,3),
		fundamento_legal varchar(500)
	);
END
GO

-- ICMS DE ENTRADA
if Not Exists(select * from sys.tables where Name = N'mxf_tmp_icms_entrada')
BEGIN
	CREATE TABLE mxf_tmp_icms_entrada ( 
		codigo_produto numeric(11),
		ean numeric(16),
		tipo_mva varchar(2),
		mva numeric(7,3),
		mva_data_ini date,
		mva_data_fim date,
		credito_outorgado numeric(1),
		gera_debito numeric(1),
		sub_rbc_alq numeric(1),
		ei_cst varchar(3),
		ei_alq numeric(7,3),
		ei_alqst numeric(7,3),
		ei_rbc numeric(7,3),
		ei_rbcst numeric(7,3),
		ed_cst varchar(3),
		ed_alq numeric(7,3),
		ed_alqst numeric(7,3),
		ed_rbc numeric(7,3),
		ed_rbcst numeric(7,3),
		es_cst varchar(3),
		es_alq numeric(7,3),
		es_alqst numeric(7,3),
		es_rbc numeric(7,3),
		es_rbcst numeric(7,3),
		nfi_cst varchar(3),
		nfd_cst varchar(3),
		nfs_csosn varchar(4),
		nf_alq numeric(7,3),
		fundamento_legal varchar(500)
	);
END
GO	

-- **********  CRIAO DAS EXIBIES **********

-- PIS E COFINS
CREATE VIEW mxf_vw_pis_cofins
AS
SELECT DISTINCT
	P.CODPROD AS codigo_produto, P.CODBARRA AS ean, P.DESCRICAO AS descritivo_produto, 
    N.CODNCM AS ncm, P.EX_IPI AS ncm_ex,
	NAT.cod_fis_natureza_receita_pis_cofins AS cod_natureza_receita, CST_PIS_E.cod_cst_pis AS pis_cst_e, 
    CST_PIS_S.cod_cst_pis AS pis_cst_s, P.PERCPIS_ENTRADA AS pis_alq_e, P.PERCPIS AS pis_alq_s, 
    CST_COFINS_E.cod_cst_cofins AS cofins_cst_e, CST_COFINS_S.cod_cst_cofins AS cofins_cst_s, 
    P.PERCCOFINS_ENTRADA AS cofins_alq_e, P.PERCCOFINS AS cofins_alq_s, GE.DESCRICAO AS secao, 
    GR.GRUPO AS grupo, SG.DESCRICAO AS subgrupo, P.INATIVO AS status
FROM
	dbo.CDPRODUTOS AS P
		INNER JOIN dbo.CDGENEROS AS GE ON P.CODGENERO = GE.CODGENERO
		INNER JOIN dbo.CDGRUPOS AS GR ON P.CODGENERO = GR.CODGENERO AND P.CODGRUPO = GR.CODGRUPO
		LEFT JOIN dbo.CDSUBGRUPOS AS SG ON P.CODGENERO = SG.CODGENERO AND P.CODGRUPO = SG.CODGRUPO AND P.CODSUBGRUPO = SG.CODSUBGRUPO
		LEFT JOIN dbo.CDNCM AS N ON P.IDNCM = N.IDNCM
		LEFT JOIN fis_natureza_receita_pis_cofins AS NAT ON P.NAT_RECEITA_COFINS = NAT.id_fis_natureza_receita_pis_cofins
		LEFT JOIN fis_cst_pis AS CST_PIS_E ON P.CODCSTPIS_ENTRADA = CST_PIS_E.id_fis_cst_pis
		LEFT JOIN fis_cst_pis AS CST_PIS_S ON P.CODCSTPIS = CST_PIS_S.id_fis_cst_pis
		LEFT JOIN fis_cst_cofins AS CST_COFINS_E ON P.CODCSTCOFINS_ENTRADA = CST_COFINS_E.id_fis_cst_cofins
		LEFT JOIN fis_cst_cofins AS CST_COFINS_S ON P.CODCSTCOFINS = CST_COFINS_S.id_fis_cst_cofins
GO
-- ICMS
CREATE VIEW mxf_vw_icms
AS
SELECT
	P.CODPROD AS codigo_produto, P.CODBARRA AS ean, NULL AS tipo_mva, P.PERCALIQSUBTRIB AS mva,
	SUBSTRING(T.SITTRIB, 2,2) AS sac_cst, a.PERCENTUAL AS sac_alq, P.PERCALIQSUBTRIB AS sac_alq_st, P.PERCREDUC AS sac_rbc, NULL AS sac_rbc_st, 
	SUBSTRING(T.SITTRIB, 2,2) AS sas_cst, a.PERCENTUAL AS sas_alq, P.PERCALIQSUBTRIB AS sas_alq_st, P.PERCREDUC AS sas_rbc, NULL AS sas_rbc_st, 
	SUBSTRING(T.SITTRIB, 2,2) AS svc_cst, a.PERCENTUAL AS svc_alq, P.PERCALIQSUBTRIB AS svc_alq_st, P.PERCREDUC AS svc_rbc, NULL AS svc_rbc_st, 
	SUBSTRING(T.SITTRIB, 2,2) AS snc_cst, a.PERCENTUAL AS snc_alq, P.PERCALIQSUBTRIB AS snc_alq_st, P.PERCREDUC AS snc_rbc, NULL AS snc_rbc_st
FROM
	CDPRODUTOS P
		INNER JOIN CDALIQUOTA A ON P.CODALIQ = A.CODALIQ
		INNER JOIN CDTRIBUTACAO T ON P.CODTRIB = T.CODTRIB
GO

-- **********  CRIAO DAS STORED PROCEDURES **********
-- RECUPERAO DA PK DA TABELA DE CADASTRO DE NCM
CREATE PROCEDURE [dbo].[MXF_SP_RECUPERA_PK_NCM]
	@CODNCM VARCHAR(20),
	@ID_RECUPERADO INT OUT
AS

BEGIN TRY
delete from cdncm 
where idncm in
(select min(idncm) from cdncm
group by codncm
having count(codncm) > 1)
END TRY
BEGIN CATCH
PRINT('Erro ao deletar NCMs duplicados')
END CATCH

IF((SELECT COUNT(*) FROM CDNCM WHERE CODNCM = '' + @CODNCM + '') > 0)
BEGIN
	SET @ID_RECUPERADO = (SELECT TOP 1 IDNCM FROM CDNCM WHERE CODNCM = '' + @CODNCM + '');
END
ELSE
BEGIN
	INSERT INTO CDNCM (IDNCM, CODNCM, DESCRICAO, DTALTER, HALTER, INATIVO)
	VALUES ((SELECT VALORID + 1 FROM IDCONTROL WHERE NOMETABELA = 'CDNCM'),'' + @CODNCM + '','Importado Mix Fiscal',
	CAST(GETDATE() AS DATE), CAST(GETDATE() AS TIME), 'N');
	IF((SELECT COUNT(*) FROM CDNCM WHERE CODNCM = '' + @CODNCM + '') > 0)
	BEGIN		
		SET @ID_RECUPERADO = (SELECT TOP 1 IDNCM FROM CDNCM WHERE CODNCM = '' + @CODNCM + '');
		UPDATE IDCONTROL SET VALORID = @ID_RECUPERADO WHERE NOMETABELA = 'CDNCM';
	END
	ELSE
	BEGIN
		SET @ID_RECUPERADO = NULL;
	END
END
GO
---------------------------------------------------------------------------------------------------------------
-- CORREO DA STORED PROCEDURE DE RECUPERAO DA PK DA TABELA DE CADASTRO DE NATUREZA DA RECEITA
CREATE PROCEDURE [dbo].[MXF_SP_RECUPERA_PK_NAT_RECEITA]
	@CST VARCHAR(5),
	@CODNAT_RECEITA INT,
	@ID_RECUPERADO INT OUT
AS
IF(@CODNAT_RECEITA IS NOT NULL)
BEGIN
	IF((SELECT COUNT(*) FROM fis_natureza_receita_pis_cofins
			WHERE cst_fis_natureza_receita_pis_cofins = '' + @CST + '' AND
			CAST(cod_fis_natureza_receita_pis_cofins AS INTEGER) =  + @CODNAT_RECEITA) > 0)
	BEGIN
		SET @ID_RECUPERADO = 
		(SELECT TOP 1 id_fis_natureza_receita_pis_cofins FROM fis_natureza_receita_pis_cofins
			WHERE cst_fis_natureza_receita_pis_cofins = '' + @CST + '' AND
			CAST(cod_fis_natureza_receita_pis_cofins AS INTEGER) =  + @CODNAT_RECEITA);
	END
	ELSE
	BEGIN
		INSERT INTO fis_natureza_receita_pis_cofins (cst_fis_natureza_receita_pis_cofins, cod_fis_natureza_receita_pis_cofins, descricao)
		VALUES ('' + @CST + '','' + @CODNAT_RECEITA + '', 'Importado Mix Fiscal');
		IF((SELECT COUNT(*) FROM fis_natureza_receita_pis_cofins
			WHERE cst_fis_natureza_receita_pis_cofins = '' + @CST + '' AND
			CAST(cod_fis_natureza_receita_pis_cofins AS INTEGER) =  + @CODNAT_RECEITA) > 0)
		BEGIN
			SET @ID_RECUPERADO = 
				(SELECT TOP 1 id_fis_natureza_receita_pis_cofins FROM fis_natureza_receita_pis_cofins
					WHERE cst_fis_natureza_receita_pis_cofins = '' + @CST + '' AND
					CAST(cod_fis_natureza_receita_pis_cofins AS INTEGER) =  + @CODNAT_RECEITA);
		END
		ELSE
		BEGIN
			SET @ID_RECUPERADO = NULL;
		END
	END
END
ELSE
BEGIN
	SET @ID_RECUPERADO = NULL;
END
GO
------------------------------------------------------------------------------------------------------------------------------------------
-- RECUPERAO DA PK DA TABELA DE CADASTRO DE CST DE COFINS
CREATE PROCEDURE [dbo].[MXF_SP_RECUPERA_PK_CST_COFINS]
	@CST VARCHAR(3),
	@TIPOES CHAR(1),
	@ID_RECUPERADO INT OUT
AS
IF((SELECT COUNT(*) FROM fis_cst_cofins
		WHERE cod_cst_cofins = '' + @CST + '') > 0)
BEGIN
	SET @ID_RECUPERADO = 
	(SELECT id_fis_cst_cofins FROM fis_cst_cofins WHERE cod_cst_cofins = '' + @CST + '');
END
ELSE
BEGIN
	INSERT INTO fis_cst_cofins (cod_cst_cofins, descricao, tipoes, tipooperacao)
	VALUES ('' + @CST + '','Importado Mix Fiscal', '' + @TIPOES + '', 'N');
	IF((SELECT COUNT(*) FROM fis_cst_cofins
		WHERE cod_cst_cofins = '' + @CST + '') > 0)
	BEGIN
		SET @ID_RECUPERADO = 
			(SELECT id_fis_cst_cofins FROM fis_cst_cofins WHERE cod_cst_cofins = '' + @CST + '');
	END
	ELSE
	BEGIN
		SET @ID_RECUPERADO = NULL;
	END
END
GO
------------------------------------------------------------------------------------------------------------------------------------------
-- RECUPERAO DA PK DA TABELA DE CADASTRO DE CST DE PIS
CREATE PROCEDURE [dbo].[MXF_SP_RECUPERA_PK_CST_PIS]
	@CST VARCHAR(3),
	@TIPOES CHAR(1),
	@ID_RECUPERADO INT OUT
AS
IF((SELECT COUNT(*) FROM fis_cst_pis
		WHERE cod_cst_pis = '' + @CST + '') > 0)
BEGIN
	SET @ID_RECUPERADO = 
	(SELECT id_fis_cst_pis FROM fis_cst_pis WHERE cod_cst_pis= '' + @CST + '');
END
ELSE
BEGIN
	INSERT INTO fis_cst_pis (cod_cst_pis, descricao, tipoes, tipooperacao)
	VALUES ('' + @CST + '','Importado Mix Fiscal', '' + @TIPOES + '', 'N');
	IF((SELECT COUNT(*) FROM fis_cst_pis
		WHERE cod_cst_pis = '' + @CST + '') > 0)
	BEGIN
		SET @ID_RECUPERADO = 
			(SELECT id_fis_cst_pis FROM fis_cst_pis WHERE cod_cst_pis = '' + @CST + '');
	END
	ELSE
	BEGIN
		SET @ID_RECUPERADO = NULL;
	END
END
GO
------------------------------------------------------------------------------------------------------------------------------------------
-- RECUPERAO DA PK DA TABELA DE CADASTRO DE TRIBUTAO
CREATE PROCEDURE [dbo].[MXF_SP_RECUPERA_PK_TRIBUTACAO]
	@CST VARCHAR(3),
	@ID_RECUPERADO INT OUT
AS
DECLARE
	@ORIGEM_CST VARCHAR(3)
IF(LEN(@CST) = 2)
BEGIN
	SET @ORIGEM_CST = '0' + @CST;
END
ELSE
BEGIN
	IF (LEN(@CST) = 1)
	BEGIN
		SET @ORIGEM_CST = '00' + @CST;
	END
	ELSE
	BEGIN
		SET @ORIGEM_CST = @CST;
	END
END
IF((SELECT COUNT(*) FROM CDTRIBUTACAO WHERE SITTRIB = '' + @ORIGEM_CST + '') > 0)
BEGIN
	SET @ID_RECUPERADO = (SELECT CODTRIB FROM CDTRIBUTACAO WHERE SITTRIB = '' + @ORIGEM_CST + '');
END
ELSE
BEGIN
	SET @ID_RECUPERADO = NULL;
END
GO
------------------------------------------------------------------------------------------------------------------------------------------
-- RECUPERAO DA PK DA TABELA DE CADASTRO DE ALQUOTA
CREATE PROCEDURE [dbo].[MXF_SP_RECUPERA_PK_ALIQUOTA]
	@PERCENTUAL DECIMAL(7,3),
	@REDUCAO DECIMAL(7,3),
	@ID_RECUPERADO INT OUT
AS
DECLARE
	@PERC_REDUZIDO DECIMAL(7,3),
	@LIMITE_INF DECIMAL(7,3),
	@LIMITE_SUP DECIMAL(7,3)
IF(@REDUCAO > 0)
BEGIN
	SET @PERC_REDUZIDO = CAST((@PERCENTUAL * (1 - @REDUCAO/100)) AS DECIMAL (7,3));
	SET @LIMITE_INF = @PERC_REDUZIDO - 0.2;
	SET @LIMITE_SUP = @PERC_REDUZIDO + 0.2;
END
ELSE
BEGIN
	SET @PERC_REDUZIDO = @PERCENTUAL;
	SET @LIMITE_INF = @PERCENTUAL;
	SET @LIMITE_SUP = @PERCENTUAL;
END
IF((SELECT COUNT(*) FROM CDALIQUOTA WHERE PERCENTUAL BETWEEN @LIMITE_INF AND @LIMITE_SUP) > 0)
BEGIN
	SET @ID_RECUPERADO = (SELECT MIN(CODALIQ) FROM CDALIQUOTA WHERE PERCENTUAL BETWEEN @LIMITE_INF AND @LIMITE_SUP);
END
ELSE
BEGIN
	SET @ID_RECUPERADO = NULL;
END
GO
---------------------------------------------------------------------------------------------------------------
-- ALTERAO DA STORED PROCEDURE DE ATUALIZAO DO CADASTRO DE PRODUTOS COM OS DADOS DA TABELA MXF_VW_PIS_COFINS
-- DEVIDO A ADIO DO CAMPO NCM_EX E O TRATAMENTO DO CST DE PIS E COFINS = 05
CREATE PROCEDURE [dbo].[MXF_SP_ATUALIZA_PISCOFINS_CDPRODUTOS]
AS 
DECLARE
	@codigo_produto numeric(11),
	@ean numeric(16),
	@ncm varchar(10),
	@ncm_ex varchar(3),
	@cod_natureza_receita numeric(4),
	@credito_presumido numeric(1),
	@pis_cst_e varchar(3),
	@pis_cst_s varchar(3),
	@pis_alq_e numeric(7,3),
	@pis_alq_s numeric(7,3),
	@cofins_cst_e varchar(3),
	@cofins_cst_s varchar(3),
	@cofins_alq_e numeric(7,3),
	@cofins_alq_s numeric(7,3),
	@fundamento_legal varchar(500),	
	@IDNCM integer,	
	@EX_IPI varchar(3),
	@NAT_RECEITA_COFINS integer,
	@NAT_RECEITA_PIS integer,
	--@CREDITO_PRESUMIDO NO EXISTE CAMPO NO CADASTRO DE PRODUTO	
	@CODCSTPIS_ENTRADA integer,
	@CODCSTPIS integer,	
	@CODCSTCOFINS_ENTRADA integer,
	@CODCSTCOFINS integer,
	-- @FUNDAMENTO_LEGAL NO EXISTE CAMPO NO CADASTRO DE PRODUTO
	@ID_RECUPERADO integer
DECLARE cursorMixFiscal CURSOR FOR
SELECT
	CODIGO_PRODUTO,EAN,NCM,NCM_EX,COD_NATUREZA_RECEITA,CREDITO_PRESUMIDO,PIS_CST_E,
	PIS_CST_S,PIS_ALQ_E,PIS_ALQ_S,COFINS_CST_E,COFINS_CST_S,COFINS_ALQ_E,
	COFINS_ALQ_S,FUNDAMENTO_LEGAL FROM MXF_TMP_PIS_COFINS
OPEN cursorMixFiscal
FETCH NEXT FROM cursorMixFiscal
INTO @codigo_produto,@ean,@ncm,@ncm_ex,@cod_natureza_receita,@credito_presumido,@pis_cst_e,
	@pis_cst_s,@pis_alq_e,@pis_alq_s,@cofins_cst_e,@cofins_cst_s,@cofins_alq_e,
	@cofins_alq_s,@fundamento_legal
WHILE @@FETCH_STATUS = 0
BEGIN
	-- PESQUISA O ID NO CADASTRO DE NCM
	EXEC MXF_SP_RECUPERA_PK_NCM @ncm, @ID_RECUPERADO = @ID_RECUPERADO OUTPUT;
	SET @IDNCM = @ID_RECUPERADO;
	-- DETERMINA A EXCEO DE IPI
	SET @EX_IPI = NULL;
	IF(@ncm_ex <> 'N')
	BEGIN
		SET @EX_IPI = @ncm_ex;
	END
	-- PESQUISA O ID NO CADASTRO DE NATUREZA DA RECEITA
	EXEC MXF_SP_RECUPERA_PK_NAT_RECEITA @cofins_cst_s, @cod_natureza_receita, @ID_RECUPERADO = @ID_RECUPERADO OUTPUT;	
	SET @NAT_RECEITA_COFINS = @ID_RECUPERADO;
	EXEC MXF_SP_RECUPERA_PK_NAT_RECEITA @pis_cst_s, @cod_natureza_receita, @ID_RECUPERADO = @ID_RECUPERADO OUTPUT;	
	SET @NAT_RECEITA_PIS = @ID_RECUPERADO;
	-- PESQUISA O ID NO CADASTRO DE CST DE PIS
	EXEC MXF_SP_RECUPERA_PK_CST_PIS @pis_cst_e, 'E', @ID_RECUPERADO = @ID_RECUPERADO OUTPUT;
	SET @CODCSTPIS_ENTRADA = @ID_RECUPERADO
	-- COMENTADO POIS NA VERSO 3.10 DA NFE J EXISTE O CST 05
	--IF @pis_cst_s = '05'
	--BEGIN
		--SET @pis_cst_s = '07'
	--END	
	EXEC MXF_SP_RECUPERA_PK_CST_PIS @pis_cst_s, 'S', @ID_RECUPERADO = @ID_RECUPERADO OUTPUT;
	SET @CODCSTPIS = @ID_RECUPERADO	
	-- PESQUISA O ID NO CADASTRO DE CST DE COFINS
	EXEC MXF_SP_RECUPERA_PK_CST_COFINS @cofins_cst_e, 'E', @ID_RECUPERADO = @ID_RECUPERADO OUTPUT;
	SET @CODCSTCOFINS_ENTRADA = @ID_RECUPERADO
	-- COMENTADO POIS NA VERSO 3.10 DA NFE J EXISTE O CST 05
	--IF @cofins_cst_s = '05'
	--BEGIN
		--SET @cofins_cst_s = '07'
	--END	
	EXEC MXF_SP_RECUPERA_PK_CST_COFINS @cofins_cst_s, 'S', @ID_RECUPERADO = @ID_RECUPERADO OUTPUT;
	SET @CODCSTCOFINS = @ID_RECUPERADO
		
	UPDATE CDPRODUTOS
	SET 
		IDNCM = @IDNCM,
		NAT_RECEITA_COFINS = @NAT_RECEITA_COFINS,
		NAT_RECEITA_PIS = @NAT_RECEITA_PIS,
		-- @credito_presumido NO EXISTE CAMPO NO CADASTRO DE PRODUTO
		CODCSTPIS_ENTRADA = @CODCSTPIS_ENTRADA,
		CODCSTPIS = @CODCSTPIS,
		PERCPIS_ENTRADA = @pis_alq_e,
		PERCPIS = @pis_alq_s,
		CODCSTCOFINS_ENTRADA = @CODCSTCOFINS_ENTRADA,
		CODCSTCOFINS = @CODCSTCOFINS,
		PERCCOFINS_ENTRADA = @cofins_alq_e,
		PERCCOFINS = @cofins_alq_s,
		-- @fundamento_legal NO EXISTE CAMPO NO CADASTRO DE PRODUTO
		DTALTER = CONVERT(DATE, GETDATE(), 103),
		HRALTER = CONVERT(TIME, GETDATE(), 114)
	WHERE CODPROD = @codigo_produto
	
	IF(@ncm_ex IS NOT NULL)
	BEGIN
		UPDATE CDPRODUTOS
		SET EX_IPI = @EX_IPI
		WHERE CODPROD = @codigo_produto
	END
	
	FETCH NEXT FROM cursorMixFiscal 
	INTO @codigo_produto,@ean,@ncm,@ncm_ex,@cod_natureza_receita,@credito_presumido,@pis_cst_e,
		@pis_cst_s,@pis_alq_e,@pis_alq_s,@cofins_cst_e,@cofins_cst_s,@cofins_alq_e,
		@cofins_alq_s,@fundamento_legal
END
CLOSE cursorMixFiscal
DEALLOCATE cursorMixFiscal
GO
------------------------------------------------------------------------------------------------------------------------------------------
-- ALTERAO DA STORED PROCEDURE DE ATUALIZAO DO CADASTRO DE PRODUTOS COM OS DADOS DA TABELA MXF_TMP_ICMS_SAIDA E MXF_TMP_ICMS_ENTRADA
-- DEVIDO A ADIO DOS CAMPOS DE REDUO DE ST E MVA E CORREO DO CODALIQECF PARA OS CSTS 60 E 70
CREATE PROCEDURE [dbo].[MXF_SP_ATUALIZA_ICMS_CDPRODUTOS]
AS 
DECLARE
	@codigo_produto numeric(11),
	@ean numeric(16),
	@snc_cst varchar(3),
	@snc_alq numeric(7,3),
	@snc_alqst numeric(7,3),	
	@mva numeric(7,3),
	@snc_rbc numeric(7,3),
	@snc_rbcst numeric(7,3),
	@ID_RECUPERADO integer,
	@CODTRIB integer,
	@CODALIQ integer,
	@CODALIQECF integer,	
	@PERCALIQSUBTRIBNF decimal(15,4)
DECLARE cursorMixFiscalSaida CURSOR FOR
SELECT CODIGO_PRODUTO, EAN, SNC_CST, SNC_ALQ, SNC_ALQST, SNC_RBC, SNC_RBCST FROM MXF_TMP_ICMS_SAIDA
OPEN cursorMixFiscalSaida
FETCH NEXT FROM cursorMixFiscalSaida
INTO @codigo_produto,@ean,@snc_cst,@snc_alq,@snc_alqst,@snc_rbc,@snc_rbcst
WHILE @@FETCH_STATUS = 0
BEGIN	
	-- PESQUISA O ID NO CADASTRO DE TRIBUTAO
	EXEC MXF_SP_RECUPERA_PK_TRIBUTACAO @snc_cst, @ID_RECUPERADO = @ID_RECUPERADO OUTPUT;
	SET @CODTRIB = @ID_RECUPERADO;
	-- PESQUISA O ID NO CADASTRO DE ALQUOTA
	EXEC MXF_SP_RECUPERA_PK_ALIQUOTA @snc_alq, 0, @ID_RECUPERADO = @ID_RECUPERADO OUTPUT;	
	SET @CODALIQ = @ID_RECUPERADO;	
	-- PESQUISA O ID NO CADASTRO DE ALQUOTA DO ECF
	IF(@snc_cst = '60' OR @snc_cst = '70')
	BEGIN
		SET @CODALIQECF = (SELECT TOP(1) CODALIQ FROM CDALIQUOTA WHERE DESCRECF LIKE 'F%')
	END
	ELSE
	BEGIN
		EXEC MXF_SP_RECUPERA_PK_ALIQUOTA @snc_alq, @snc_rbc, @ID_RECUPERADO = @ID_RECUPERADO OUTPUT;	
		SET @CODALIQECF = @ID_RECUPERADO;	
	END
	
	UPDATE CDPRODUTOS
	SET 
		CODTRIB = @CODTRIB,
		CODALIQ = @CODALIQ,
		CODALIQNF = @CODALIQ,
		CODALIQECF = @CODALIQECF,		
		PERCALIQSUBTRIBNF = @snc_alqst, -- ALIQ DE ST
		PERCREDUC = @snc_rbc,
		PERCREDUCST = @snc_rbcst,
		DTALTER = CONVERT(DATE, GETDATE(), 103),
		HRALTER = CONVERT(TIME, GETDATE(), 114)
	WHERE CODPROD = @codigo_produto	
FETCH NEXT FROM cursorMixFiscalSaida 
INTO @codigo_produto,@ean,@snc_cst,@snc_alq,@snc_alqst,@snc_rbc,@snc_rbcst
END
CLOSE cursorMixFiscalSaida
DEALLOCATE cursorMixFiscalSaida

DECLARE cursorMixFiscalEntrada CURSOR FOR
-- PESQUISA SOMENTE O MVA PREENCHIDO POIS CASO SEJA NULO NO DEVER SER GRAVADO	
SELECT CODIGO_PRODUTO, EAN, MVA FROM MXF_TMP_ICMS_ENTRADA WHERE MVA IS NOT NULL
OPEN cursorMixFiscalEntrada
FETCH NEXT FROM cursorMixFiscalEntrada
INTO @codigo_produto,@ean,@mva
WHILE @@FETCH_STATUS = 0
BEGIN		
	UPDATE CDPRODUTOS
	SET 		
		PERCALIQSUBTRIB = @mva, -- MVA
		DTALTER = CONVERT(DATE, GETDATE(), 103),
		HRALTER = CONVERT(TIME, GETDATE(), 114)
	WHERE CODPROD = @codigo_produto	
FETCH NEXT FROM cursorMixFiscalEntrada 
INTO @codigo_produto,@ean,@mva
END
CLOSE cursorMixFiscalEntrada
DEALLOCATE cursorMixFiscalEntrada
GO

------------------------------------------------------------------------------------------------------------------------------------------
-- **********  CRIAO DO USURIO **********
IF NOT EXISTS(SELECT * FROM MASTER.DBO.SYSLOGINS WHERE NAME = 'MIX_FISCAL')
	CREATE LOGIN MIX_FISCAL WITH PASSWORD = 'mix1234';
GO
IF NOT EXISTS(SELECT * FROM SYSUSERS WHERE NAME = 'MIX_FISCAL')
   CREATE USER MIX_FISCAL FROM LOGIN MIX_FISCAL;
GO

-- **********  CRIAO DAS PERMISSES DE ACESSO **********
GRANT SELECT, UPDATE, INSERT, DELETE ON mxf_tmp_pis_cofins TO MIX_FISCAL
GRANT SELECT, UPDATE, INSERT, DELETE ON mxf_tmp_icms_saida TO MIX_FISCAL
GRANT SELECT, UPDATE, INSERT, DELETE ON mxf_tmp_icms_entrada TO MIX_FISCAL

GRANT SELECT ON mxf_vw_pis_cofins TO MIX_FISCAL
GRANT SELECT ON mxf_vw_icms TO MIX_FISCAL
GO
